## Pastekan
pastekan adalah website paste kode / teks sederhana.

## install 
```
pip install pastekan
```

## penggunaan 
```
pastekan myfile.txt
```
atau 
```
echo "hi" | pastekan
```

## options
```
$ pastekan -h
pastekan - a CLI client for pastekan server.

Usage:
    pastekan [-r] [-]
    pastekan [-r] FILE

-             read from stdin.
FILE          read from a file.

-h --help     show this message.
-v --version  show version information.
-r --raw      return a URL to the raw paste data.
```